==> ssscoring-2.7.3-py3-none-any.whl: ssscoring/resources/instructions.md <==
# Speed Skydiving Scoring

## To score one or more jumps

1. Set the starting/drop zone ground-level elevation in meters by selecting the
   drop zone name from the list or entering the value in field
1. Open one or more FlySight CSV files by clicking on the Track files uploading
   button or drop the files in there
1. Wait a few seconds, the results will be displayed in the main window
1. When done, press the **Clear** button to remove all the track files from the
   uploader, or press the **x** control in the drop zone or elevation fields to
   wipe everything off and start over


## Main window

- The main window displays these instructions or the results of evaluating the
  track files
- Results are displayed in individual tabs
  - The first tab summarizes all the jumps input in the track files uploading
    box
  - Details of each jump appear in a dedicated tab, identified by the track
    file's name or "tag"


## Tips and tricks

- You can add or remove files from the track file uploader as you go, without
  having to clear every time; SSScore uses the DZ elevation to validate the
  jump but otherwise doesn't check if two track files come from the same DZ
- If you are running this from the web and leave the machine unattended for
  several minutes, the **Clear** and other buttons will stop responding because
  the cloud server went to sleep.  Press the _Reload_ button in your browser to
  start a new session
- You can zoom in or out of the map views using expand/contract gestures on a
  trackpad, with the mouse, or pinching the screen of your mobile device


---
Copyright &copy; 2019-2025 by Eugene Ciurana DBA pr3d4t0r Speed Skydiving Team,
and CIME Sofware Ltd.

Released under the BSD-3 open source license.

==> ssscoring-2.8.5-py3-none-any.whl: ssscoring/resources/instructions.md <==
# Speed Skydiving Scoring

## To score one or more jumps

1. Set the starting/drop zone ground-level elevation in meters by **selecting
   the drop zone** name from the list or entering the value in the field **DZ
   elevation in meters**
1. Open one or more FlySight CSV files by clicking on the **Track files**
   upload button or drop the files in there
1. Wait a few seconds, the results will be displayed in the main window
1. When done, press the **Clear** button to remove all the track files from the
   uploader, or press the **x** control in the drop zone or elevation fields to
   wipe everything off and start over


## Main window

- The main window displays these instructions or the results of evaluating the
  track files
- Results are displayed in individual tabs
  - The first tab summarizes all the jumps input in the track files uploading
    box
  - Details of each jump appear in a dedicated tab, identified by the track
    file's name or "tag"


## Tips and tricks

- You can add or remove files from the track file uploader as you go, without
  having to clear every time; SSScore uses the DZ elevation to validate the
  jump but otherwise doesn't enforce if two track files come from the same DZ
- If you are running this from the web and leave the machine unattended for
  several minutes, the **Clear** and other buttons will stop responding because
  the cloud server went to sleep.  Press your browser's _Reload_ button to
  start a new session
- You can zoom in or out of the map views using expand/contract gestures on a
  trackpad, with the mouse, or pinching the screen of your mobile device


---
Copyright &copy; 2019-2025 by Eugene Ciurana DBA **pr3d4t0r Speed Skydiving
Team**, and CIME Sofware Ltd.

Released under the BSD-3 open source license.
